# Load required packages

library(readxl)
library(survminer)
library(survival)

# Upload data 

OsHV1_allfamilies <- read_excel("OsHV1_allfamilies.xlsx")

Master <- OsHV1_allfamilies
# All 20 families, all viruses and control

# Virus Labels
  # CA = OsHV-1 TB
  # FRA = French µvar
  # AUS = AUS µvar
 
# Remove family 60 and continue

Master19 <- Master[Master$Family == "5"|Master$Family == "11"|Master$Family == "67"|
                     Master$Family == "74"|Master$Family == "10"|Master$Family == "14"|
                     Master$Family == "17"|Master$Family == "29"|Master$Family == "40"|
                     Master$Family == "46"|Master$Family == "47"|Master$Family == "52"|
                     Master$Family == "68"|Master$Family == "70"|Master$Family == "73"|
                     Master$Family == "75"|Master$Family == "87"|Master$Family == "53"|
                     Master$Family == "72",]

 ##################### Data for all 19 oyster families #####################

## Pairwise comparisons by oyster family
pc19fam <- pairwise_survdiff(Surv(Day, Status) ~ Family, data = Master19)
pc19fam

## Pairwise comparisons by virus 
pc19virus <- pairwise_survdiff(Surv(Day, Status) ~ Virus, data = Master19)
pc19virus

## Create a survival object and plot
Surv19 <- Surv(time = Master19$Day, event = Master19$Status)
fit.surv19 <- survfit(formula = Surv19 ~ Virus, data = Master19)
ggsurvplot(fit.surv19, data = Master19, xlim = c(3,7), xlab = "Day")

# Get Chi square values for survival
cs19 <- survdiff(Surv(Day, Status) ~ Virus, data = Master19)
cs19

## Survival probability for all of the 19 families by family and virus
summary(survfit(Surv(Day, Status) ~ Virus, data = Master19), times = 7)
summary(survfit(Surv(Day, Status) ~ Family, data = Master19), times = 7)


##################### Survival probability for all families #####################
#####################     expose to just FRA and AUS        #####################

## Subset the data 

MasterFRA_AUS_19 <- Master19[Master19$Virus == "FRA"|Master19$Virus == "AUS",]

summary(survfit(Surv(Day, Status) ~ Family + Virus, data = MasterFRA_AUS_19), times = 7)
pcfraausfam <- pairwise_survdiff(Surv(Day, Status) ~ Family, data = MasterFRA_AUS_19)
pcfraausfam

## Get coxph values

# Change virus order first 

Master19$Virus <- factor(Master19$Virus, levels = c("CON", "CA", "AUS", "FRA"), 
                         labels = c("Control", "OsHV-1 TB", "AUS µvar", "FRA µvar"))

fit.coxph <- coxph(Surv19 ~ Virus, data = Master19)
fit.coxph

##################### Data for the 5 h/l families across viruses #####################

## Subset for the 5 families h/l families, remove control

Fam5 <- Master[Master$Family == "5"|Master$Family == "11"|Master$Family == "53"
               |Master$Family == "67"|Master$Family == "74",]

Fam5 <- Fam5[Fam5$Virus == "AUS"|Fam5$Virus == "CA"|Fam5$Virus == "FRA",]

## Pairwise comparisons by family 

pc <- pairwise_survdiff(Surv(Day, Status) ~ Family, data = Fam5)
pc

## Get Chi square values 
cs5 <- survdiff(Surv(Day, Status) ~ Family, data = Fam5)
cs5

## Fit a survival object

Fam5Surv <- Surv(time = Fam5$Day, event = Fam5$Status)
fit.Fam5 <- survfit(formula = Fam5Surv ~ Family, data = Fam5)
summary(survfit(Surv(Day, Status) ~ Family, data = Fam5), times = 7)

##################### Data for individual oyster families #####################

## Subset individual families and remove the controls 

Master$Virus <- factor(Master$Virus, levels = c("CON", "CA", "AUS", "FRA"))

Fam5.1 <- Master[Master$Family =='5',]
Fam11 <- Master[Master$Family =='11',]
Fam67 <- Master[Master$Family == '67',]
Fam53 <- Master[Master$Family == '53',]
Fam74 <- Master[Master$Family == '74',]

### Fam5 ####

pc5 <- pairwise_survdiff(Surv(Day, Status) ~ Virus, data = Fam5.1)
pc5

cs5 <- survdiff(Surv(Day, Status) ~ Virus, data = Fam5.1)
cs5

Fam5.1Surv <- Surv(time = Fam5.1$Day, event = Fam5.1$Status)
fit.Fam5.1 <- survfit(formula = Fam5.1Surv ~ Virus, data = Fam5.1)

summary(survfit(Surv(Day, Status) ~ Virus, data = Fam5.1), times = 7)


### Fam11 ###

pc11 <- pairwise_survdiff(Surv(Day, Status) ~ Virus, data = Fam11)
pc11

cs11 <- survdiff(Surv(Day, Status) ~ Virus, data = Fam11)
cs11

Fam11Surv <- Surv(time = Fam11$Day, event = Fam11$Status)
fit.Fam11 <- survfit(formula = Fam11Surv ~ Virus, data = Fam11)
summary(survfit(Surv(Day, Status) ~ Virus, data = Fam11), times = 7)

### Fam 53 ###

pc53 <- pairwise_survdiff(Surv(Day, Status) ~ Virus, data = Fam53)
pc53

cs53 <- survdiff(Surv(Day, Status) ~ Virus, data = Fam53)
cs53

Fam53Surv <- Surv(time = Fam53$Day, event = Fam53$Status)
fit.Fam53 <- survfit(formula = Fam53Surv ~ Virus, data = Fam53)
summary(survfit(Surv(Day, Status) ~ Virus, data = Fam53), times = 7)

### Fam 67 ###

pc67 <- pairwise_survdiff(Surv(Day, Status) ~ Virus, data = Fam67)
pc67

cs67 <- survdiff(Surv(Day, Status) ~ Virus, data = Fam67)
cs67

Fam67Surv <- Surv(time = Fam67$Day, event = Fam67$Status)
fit.Fam67 <- survfit(formula = Fam67Surv ~ Virus, data = Fam67)
summary(survfit(Surv(Day, Status) ~ Virus, data = Fam67), times = 7)

### Fam 74 ###

pc74 <- pairwise_survdiff(Surv(Day, Status) ~ Virus, data = Fam74)
pc74

cs74 <- survdiff(Surv(Day, Status) ~ Virus, data = Fam74)
cs74

Fam74Surv <- Surv(time = Fam74$Day, event = Fam74$Status)
fit.Fam74 <- survfit(formula = Fam74Surv ~ Virus, data = Fam74)
summary(survfit(Surv(Day, Status) ~ Virus, data = Fam74), times = 7)

