# Load required packages

library(readxl)
library(ggpubr)

# Load the data 

A <- read_excel("Survival_correlations_12.8.20.xlsx")

# Contains data from Agnew et al. 2020 and Divilov et al. 2019
  # Divilov, K.; Schoolfield, B.; Morga, B.; Dégremont, L.; Burge, C.A.; Cortez, D.M.; Friedman, C.S.; Fleener, G.B.; Dumbauld, B.R.; Langdon, C. First evaluation of resistance to both a California OsHV-1 variant and a French OsHV-1 microvariant in Pacific oysters. BMC Genet. 2019, 20, doi:10.1186/s12863-019-0791-3.

# Virus Labels 
  # CA = OsHV-1 TB
  # FRA = French µvar 
  # AUS = Australian µvar

# "SURV" = % survival

# Divilov et al. 2019 labels
  # KDSURVLAB = Divilov et al. 2019 laboratory data - exposed to the French µvar
  # KDSURVTB = Divilov et al. 2019 field experiment - exposed to OsHV-1 TB

############ Agnew et al. 2020 only #############

#### Check for normality 

shapiro.test(A$CASURV)
ggqqplot(A$CASURV, ylab = "CA")

shapiro.test(A$FRASURV)
ggqqplot(A$FRASURV, ylab = "FRA")


shapiro.test(A$AUSSURV)
ggqqplot(A$AUSSURV, ylab = "AUS")

# CA data not normal - run Spearman correlations for non-normality

cor.test(A$CASURV,A$FRASURV, method = "spearman")
ggscatter(A, x = "FRASURV", y = "CASURV", cor.method = "spearman",
          add = "reg.line", conf.int = TRUE, 
          cor.coef = TRUE,
          xlab = "Survival CA", ylab = "Survival FRA")


cor.test(A$CASURV, A$AUSSURV, method = "spearman")
ggscatter(A, x = "AUSSURV", y = "CASURV", cor.method = "spearman",
          add = "reg.line", conf.int = TRUE, 
          cor.coef = TRUE,
          xlab = "Survival AUS", ylab = "Survival CA")

cor.test(A$AUSSURV, A$FRASURV, method = "spearman")
ggscatter(A, x = "AUSSURV", y = "FRASURV", 
          add = "reg.line", conf.int = TRUE, cor.method = "spearman",
          cor.coef = TRUE,
          xlab = "Survival AUS", ylab = "Survival FRA")


############ Agnew et al. 2020 compared to Divlov et al. 2019 #############

### Check normality 

shapiro.test(A$KDSURVTB)
shapiro.test(A$KDSURVLAB)

# Run correlations with Spearman correlation due to non-normality

cor.test(A$CASURV, A$KDSURVTB, method = "spearman")
ggscatter(A, x = "CASURV", y = "KDSURVTB", cor.method = "spearman",
          add = "reg.line", conf.int = TRUE, 
          cor.coef = TRUE,
          xlab = "Survival CA", ylab = "Survival KDTB")

cor.test(A$CASURV, A$KDSURVLAB, method = "spearman")
ggscatter(A, x = "CASURV", y = "KDSURVLAB", cor.method = "spearman",
          add = "reg.line", conf.int = TRUE, 
          cor.coef = TRUE,
          xlab = "Survival CA", ylab = "Survival KD LAB")

cor.test(A$FRASURV, A$KDSURVLAB, method = "spearman")
ggscatter(A, x = "FRASURV", y = "KDSURVLAB", cor.method = "spearman",
          add = "reg.line", conf.int = TRUE, 
          cor.coef = TRUE,
          xlab = "Survival FRA", ylab = "Survival KD LAB")

cor.test(A$FRASURV, A$KDSURVTB, method = "spearman")
ggscatter(A, x = "FRASURV", y = "KDSURVTB", cor.method = "spearman",
          add = "reg.line", conf.int = TRUE, 
          cor.coef = TRUE,
          xlab = "Survival FRA", ylab = "Survival KD TB")


